Clazz.declarePackage("J.api.js");
Clazz.declareInterface(J.api.js, "JmolToJSmolInterface", javajs.api.js.J2SObjectInterface);
;//5.0.1-v7 Mon May 19 12:57:35 CDT 2025
